@@ -2,8 +2,8 @@ package Net::Syndic8::FeedObj;
 use 5.008002;
 use strict;
 use warnings;
-use HTML::WebDAO::Base;
-our @ISA = qw(HTML::WebDAO::Base);
+use Net::Syndic8::Base;
+our @ISA = qw(Net::Syndic8::Base);
 our $VERSION = '0.01';
 attributes (qw/ID Collection Loaded _data/);
 # Preloaded methods go here.
@@ -42,7 +42,7 @@ Net::Syndic8::FeedObj - Class for incapsulate results of requests.
 =head1 DESCRIPTION
 
 Net::Syndic8::FeedObj - Class for incapsulate results of requests.
-It have method I<DATA> for access to fetched results and support B<LazyLoad>.
+It have method I<DATA> for access to fetched results and support LazyLoad.
 
 =head1 SEE ALSO
 
